@@ -3,13 +3,15 @@ Main interface for iot1click-devices service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.iot1click_devices import IoT1ClickDevicesServiceClient
+    from mypy_boto3_iot1click_devices import IoT1ClickDevicesServiceClient
 
     session = boto3.Session()
 
     client: IoT1ClickDevicesServiceClient = boto3.client("iot1click-devices")
     session_client: IoT1ClickDevicesServiceClient = session.client("iot1click-devices")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
