@@ -3,8 +3,11 @@ Main interface for iot1click-devices service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.iot1click_devices import (
+
+    from mypy_boto3_iot1click_devices import IoT1ClickDevicesServiceClient
+    from mypy_boto3_iot1click_devices import (
         ListDeviceEventsPaginator,
         ListDevicesPaginator,
     )
@@ -13,6 +16,7 @@ Usage::
 
     list_device_events_paginator: ListDeviceEventsPaginator = client.get_paginator("list_device_events")
     list_devices_paginator: ListDevicesPaginator = client.get_paginator("list_devices")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
